@@ -1,9 +1,9 @@
 package Log::ger::UseDataDumper;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-04'; # DATE
+our $DATE = '2020-06-06'; # DATE
 our $DIST = 'Log-ger-UseDataDumper'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Data::Dumper ();
 use Log::ger ();
@@ -59,7 +59,7 @@ Log::ger::UseDataDumper - Use Data::Dumper (with nicer defaults) to dump data st
 
 =head1 VERSION
 
-This document describes version 0.004 of Log::ger::UseDataDumper (from Perl distribution Log-ger-UseDataDumper), released on 2020-06-04.
+This document describes version 0.005 of Log::ger::UseDataDumper (from Perl distribution Log-ger-UseDataDumper), released on 2020-06-06.
 
 =head1 SYNOPSIS
 
@@ -105,9 +105,29 @@ L<Log::ger>
 
 L<Data::Dumper>
 
-Other modules to set data dumper for Log::ger: L<Log::ger::UseDataDump>,
-L<Log::ger::UseDataDumpColor>, L<Log::ger::UseDataDumpObjectAsString>,
-L<Log::ger::UseDataDumpOptions>, L<Log::ger::UseDataPrinter>.
+Other modules to set data dumper for Log::ger:
+
+=over
+
+=item * L<Log::ger::UseBaheForDump>
+
+=item * L<Log::ger::UseDataDump>
+
+=item * L<Log::ger::UseDataDumpColor>
+
+=item * L<Log::ger::UseDataDumpObjectAsString>
+
+=item * L<Log::ger::UseDataDumpOptions>
+
+=item * L<Log::ger::UseDataDumperCompact>
+
+=item * L<Log::ger::UseDataPrinter>
+
+=item * L<Log::ger::UseJSONForDump>
+
+=item * L<Log::ger::UseYAMLForDump>
+
+=back
 
 =head1 AUTHOR
 
